Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2571)

Unified Diff: chrome/browser/instant/instant_controller_delegate.h

Issue 10915217: Hook up SetInstantPreviewHeight for ChromeOS. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Move hidden notification, too. Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/instant/instant_controller.cc ('k') | chrome/browser/instant/instant_loader.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/instant/instant_controller_delegate.h
diff --git a/chrome/browser/instant/instant_controller_delegate.h b/chrome/browser/instant/instant_controller_delegate.h
index 908dd7e746ceffc6bcdf79ccc2f6871439699f1d..ce7d9e5c24f029044e4cadc4f93f1742b0b8bb47 100644
--- a/chrome/browser/instant/instant_controller_delegate.h
+++ b/chrome/browser/instant/instant_controller_delegate.h
@@ -22,8 +22,8 @@ class Rect;
// (note that it may return NULL).
class InstantControllerDelegate {
public:
- // Show the preview.
- virtual void ShowInstant() = 0;
+ // Show the preview with the given |height|.
+ virtual void ShowInstant(int height, InstantSizeUnits units) = 0;
// Hide any preview currently being shown.
virtual void HideInstant() = 0;
« no previous file with comments | « chrome/browser/instant/instant_controller.cc ('k') | chrome/browser/instant/instant_loader.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698